@@ -437,12 +437,24 @@ function proon_action_effect_or_prune_all(&$p, &$outcome, &$notice, &$imapStr, $
     }
   }
   $consider_unsubs = proon_effective_option($p, PROON_O_U_UNSUBSCRIBED);
-  foreach ($p[PROON_F_DATE_OR_SIZE_OR_COUNT] as $target => $junk) {
+  // want to look at any folder with a user-specified span or any of
+  // the site preferences; we don't care about the values
+  $those_with_site_spans = array_merge($p[PROON_P_SITE][PROON_O_F_DATE_SPAN],
+				       $p[PROON_P_SITE][PROON_O_F_SIZE_SPAN],
+				       $p[PROON_P_SITE][PROON_O_F_COUNT_SPAN]);
+
+  $all_your_bases = array_merge($p[PROON_F_DATE_OR_SIZE_OR_COUNT], $those_with_site_spans);
+
+  foreach ($all_your_bases as $target => $junk) {
     if ($target == $tbox  &&  $trash_order != PROON_O_U_T_NATURAL) continue;
-    $issubbed = proon_is_subscribed($p, $target, $imapStr);
-    if (! $issubbed  &&  ! $consider_unsubs) continue;
-    $target_manual_only = proon_effective_folder_option($p, PROON_O_F_MANUAL_ONLY, $target);
-    if (! $manual  &&  $target_manual_only) continue;
+    // we're always going to look at folders mentioned in site preference spans;
+    // otherwise, only look at them conditionally if not subscribed
+    if (! array_key_exists($target, $those_with_site_spans)) {
+      $issubbed = proon_is_subscribed($p, $target, $imapStr);
+      if (! $issubbed  &&  ! $consider_unsubs) continue;
+      $target_manual_only = proon_effective_folder_option($p, PROON_O_F_MANUAL_ONLY, $target);
+      if (! $manual  &&  $target_manual_only) continue;
+    }
     if (!proon_mailbox_exists($p, $target, $imapStr)) continue;
     if (false === proon_action_now_or_effect($p, $target, $outcome, $imapStr, $doit)) {
       $pruneall_notice = true;
