@@ -126,6 +126,30 @@ function proon_prune_hook_function($h) {
 
 }
 
+/*
+ * The stand-alone proon options page setup.
+ */
+function proon_optpage($h) {
+  global $optpage_blocks;
+  proon_locale_on();
+  $optpage_blocks[] = array(
+			    'name' => PROON_PRUNING_DOTDOTDOT,
+			    'url' => SM_PATH . 'plugins/proon/form.php',
+			    'desc' => _("Options for Pruning Folders"),
+			    'js' => FALSE
+			    );
+  proon_locale_off();
+}
+
+/*
+ * The stand-alone proon options page redirect.
+ */
+function proon_optpage_loadinfo($h) {
+  global $optpage_name, $optpage_file;
+  $optpage_name = PROON_PRUNING_DOTDOTDOT;
+  $optpage_file = SM_PATH . 'plugins/proon/form.php';
+}
+
 /**
  * This is called for both options_folder_inside and left_main_after
  * to put in links to the proon form page.
@@ -177,7 +201,7 @@ function proon_onetime($h) {
   if (is_array($h)) $h = $h[0];
   global $data_dir, $username;
   global $proon_log_verbose;
-  $proon_log_verbose && proon_log("othk u=$username d=$data_dir s=" . SQ_SESSION);
+  $proon_log_verbose && proon_log("othk u=$username d=$data_dir s=" . SQ_SESSION . " sp=" . SM_PATH);
   if (! $data_dir  ||  ! $username) return;
 
   global $right_frame;
@@ -191,6 +215,7 @@ function proon_onetime($h) {
   }
   if ($proon_onetime) {
     if ($proon_onetime !== true) {
+      $proon_log_verbose && proon_log("proon_onetime=" . $proon_onetime);
       $right_frame = $proon_onetime;
     }
     return; // already been here
@@ -209,7 +234,9 @@ function proon_onetime($h) {
     if (is_numeric($apst)  &&  $apst > 0) {
       global $proon_redirect_apst;
       if ($proon_redirect_apst  ||  $proon_onetime_everybody) {
-	$right_frame = '../plugins/proon/form.php';
+	//$right_frame = '../plugins/proon/form.php';
+	$right_frame = 'options.php';
+	sqsession_register('proon', 'optpage');
 	sqsession_register($right_frame, 'proon_onetime');
       }
       else {
@@ -218,7 +245,9 @@ function proon_onetime($h) {
     }
   }
   if ($proon_onetime_everybody) {
-    $right_frame = '../plugins/proon/form.php';
+    //$right_frame = '../plugins/proon/form.php';
+    $right_frame = 'options.php';
+    sqsession_register('proon', 'optpage');
     sqsession_register($right_frame, 'proon_onetime');
   }
 }
