@@ -157,7 +157,9 @@ function proon_get_spans(&$p, &$target) {
   $rawsize = (isset($p[PROON_O_F_SIZE_SPAN][$target]) ? $p[PROON_O_F_SIZE_SPAN][$target] : '');
   $rawcount = (isset($p[PROON_O_F_COUNT_SPAN][$target]) ? $p[PROON_O_F_COUNT_SPAN][$target] : '');
   $m = proon_check_spans($rawdate, $rawsize, $rawcount);
-  if ($m !== true) return $m;
+  // We used to complain about lack of any user-defined spans, but site preferences
+  // can override anyhow.
+  //if ($m !== true) return $m;
   $spans[PROON_SPAN_DATE] = proon_minimum_folder_option($p, PROON_O_F_DATE_SPAN, $target, 'd');
   $spans[PROON_SPAN_SIZE] = proon_minimum_folder_option($p, PROON_O_F_SIZE_SPAN, $target, 's');
   $spans[PROON_SPAN_COUNT] = proon_minimum_folder_option($p, PROON_O_F_COUNT_SPAN, $target, 'c');;
